##  Scope
This out-of-the-box integration is available for Team and Enterprise accounts. To access Lucidchart, each user must individually set up the integration within their SAP LeanIX workspace using their personal profiles.
